==> mesa_18.0.0~rc5.orig.tar.gz: mesa-18.0.0-rc5/src/mesa/program/programopt.h <==
/*
 * Mesa 3-D graphics library
 *
 * Copyright (C) 1999-2007  Brian Paul   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */


#ifndef PROGRAMOPT_H
#define PROGRAMOPT_H 1

#include "main/mtypes.h"


#ifdef __cplusplus
extern "C" {
#endif


extern void
_mesa_insert_mvp_code(struct gl_context *ctx, struct gl_program *vprog);

extern void
_mesa_append_fog_code(struct gl_context *ctx, struct gl_program *fprog,
                      GLenum fog_mode, GLboolean saturate);

extern void
_mesa_count_texture_indirections(struct gl_program *prog);

extern void
_mesa_count_texture_instructions(struct gl_program *prog);

extern void
_mesa_remove_output_reads(struct gl_program *prog, gl_register_file type);

extern void
_mesa_program_fragment_position_to_sysval(struct gl_program *prog);

#ifdef __cplusplus
}
#endif

#endif /* PROGRAMOPT_H */

==> mesa_20.0.8.orig.tar.gz: mesa-20.0.8/src/mesa/program/programopt.h <==
/*
 * Mesa 3-D graphics library
 *
 * Copyright (C) 1999-2007  Brian Paul   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */


#ifndef PROGRAMOPT_H
#define PROGRAMOPT_H 1

#include "main/glheader.h"
#include "prog_parameter.h"


#ifdef __cplusplus
extern "C" {
#endif

struct gl_context;
struct gl_program;

extern void
_mesa_insert_mvp_code(struct gl_context *ctx, struct gl_program *vprog);

extern void
_mesa_append_fog_code(struct gl_context *ctx, struct gl_program *fprog,
                      GLenum fog_mode, GLboolean saturate);

extern void
_mesa_count_texture_indirections(struct gl_program *prog);

extern void
_mesa_count_texture_instructions(struct gl_program *prog);

extern void
_mesa_remove_output_reads(struct gl_program *prog, gl_register_file type);

extern void
_mesa_program_fragment_position_to_sysval(struct gl_program *prog);

#ifdef __cplusplus
}
#endif

#endif /* PROGRAMOPT_H */
